| Copyright | (c) 2013-2023 Brendan Hay |
|---|---|
| License | Mozilla Public License, v. 2.0. |
| Maintainer | Brendan Hay |
| Stability | auto-generated |
| Portability | non-portable (GHC extensions) |
| Safe Haskell | Safe-Inferred |
| Language | Haskell2010 |
Amazonka.KMS.Types.AliasListEntry
Description
Synopsis
- data AliasListEntry = AliasListEntry' {}
- newAliasListEntry :: AliasListEntry
- aliasListEntry_aliasArn :: Lens' AliasListEntry (Maybe Text)
- aliasListEntry_aliasName :: Lens' AliasListEntry (Maybe Text)
- aliasListEntry_creationDate :: Lens' AliasListEntry (Maybe UTCTime)
- aliasListEntry_lastUpdatedDate :: Lens' AliasListEntry (Maybe UTCTime)
- aliasListEntry_targetKeyId :: Lens' AliasListEntry (Maybe Text)
Documentation
data AliasListEntry Source #
Contains information about an alias.
See: newAliasListEntry smart constructor.
Constructors
| AliasListEntry' | |
Fields
| |
Instances
newAliasListEntry :: AliasListEntry Source #
Create a value of AliasListEntry with all optional fields omitted.
Use generic-lens or optics to modify other optional fields.
The following record fields are available, with the corresponding lenses provided for backwards compatibility:
$sel:aliasArn:AliasListEntry', aliasListEntry_aliasArn - String that contains the key ARN.
$sel:aliasName:AliasListEntry', aliasListEntry_aliasName - String that contains the alias. This value begins with alias/.
$sel:creationDate:AliasListEntry', aliasListEntry_creationDate - Date and time that the alias was most recently created in the account
and Region. Formatted as Unix time.
$sel:lastUpdatedDate:AliasListEntry', aliasListEntry_lastUpdatedDate - Date and time that the alias was most recently associated with a KMS key
in the account and Region. Formatted as Unix time.
$sel:targetKeyId:AliasListEntry', aliasListEntry_targetKeyId - String that contains the key identifier of the KMS key associated with
the alias.
aliasListEntry_aliasArn :: Lens' AliasListEntry (Maybe Text) Source #
String that contains the key ARN.
aliasListEntry_aliasName :: Lens' AliasListEntry (Maybe Text) Source #
String that contains the alias. This value begins with alias/.
aliasListEntry_creationDate :: Lens' AliasListEntry (Maybe UTCTime) Source #
Date and time that the alias was most recently created in the account and Region. Formatted as Unix time.
aliasListEntry_lastUpdatedDate :: Lens' AliasListEntry (Maybe UTCTime) Source #
Date and time that the alias was most recently associated with a KMS key in the account and Region. Formatted as Unix time.
aliasListEntry_targetKeyId :: Lens' AliasListEntry (Maybe Text) Source #
String that contains the key identifier of the KMS key associated with the alias.