| Copyright | (c) 2013-2023 Brendan Hay |
|---|---|
| License | Mozilla Public License, v. 2.0. |
| Maintainer | Brendan Hay |
| Stability | auto-generated |
| Portability | non-portable (GHC extensions) |
| Safe Haskell | Safe-Inferred |
| Language | Haskell2010 |
Amazonka.KMS.Types.KeyListEntry
Description
Synopsis
Documentation
data KeyListEntry Source #
Contains information about each entry in the key list.
See: newKeyListEntry smart constructor.
Constructors
| KeyListEntry' | |
Instances
newKeyListEntry :: KeyListEntry Source #
Create a value of KeyListEntry with all optional fields omitted.
Use generic-lens or optics to modify other optional fields.
The following record fields are available, with the corresponding lenses provided for backwards compatibility:
$sel:keyArn:KeyListEntry', keyListEntry_keyArn - ARN of the key.
$sel:keyId:KeyListEntry', keyListEntry_keyId - Unique identifier of the key.
keyListEntry_keyArn :: Lens' KeyListEntry (Maybe Text) Source #
ARN of the key.
keyListEntry_keyId :: Lens' KeyListEntry (Maybe Text) Source #
Unique identifier of the key.